@@ -4,7 +4,7 @@ This problem is resolved by using PyTest version 2.8.6 or above.
 
 To run these doctests, install pytest and run:
 
-    $ py.test --doctest-modules pytest_doctest_test.py
+    $ pytest --doctest-modules pytest_doctest_test.py
 
 Add `-s` option to enable print statements.
 """
@@ -12,10 +12,10 @@ from __future__ import unicode_literals
 
 
 def make_file_factory(func_name, fake, result):
-    """ Return a simple function with parametrized doctest. """
+    """Return a simple function with parametrized doctest."""
 
-    def make_file(name, content=''):
-        with open(name, 'w') as f:
+    def make_file(name, content=""):
+        with open(name, "w") as f:
             f.write(content)
 
     make_file.__doc__ = """
@@ -29,20 +29,20 @@ def make_file_factory(func_name, fake, result):
         """.format(
         command="getfixture('fs')" if fake else "pass",
         func_name=func_name,
-        result=result)
+        result=result,
+    )
 
     return make_file
 
 
-passes = make_file_factory('passes', fake=False, result=True)
-passes_too = make_file_factory('passes_too', fake=True, result=True)
+passes = make_file_factory("passes", fake=False, result=True)
+passes_too = make_file_factory("passes_too", fake=True, result=True)
 
-passes_too.__doc__ = passes_too.__doc__.replace('>>> os.remove(name)',
-                                                '>>> pass')
+passes_too.__doc__ = passes_too.__doc__.replace(">>> os.remove(name)", ">>> pass")
 
-fails = make_file_factory('fails', fake=False, result=False)
+fails = make_file_factory("fails", fake=False, result=False)
 
 # Pytest versions below 2.8.6 raise an internal error when running
 # these doctests:
-crashes = make_file_factory('crashes', fake=True, result=False)
-crashes_too = make_file_factory(') SyntaxError', fake=True, result=False)
+crashes = make_file_factory("crashes", fake=True, result=False)
+crashes_too = make_file_factory(") SyntaxError", fake=True, result=False)
